@@ -5,7 +5,7 @@
  * $Author: kou $
  * $Date: 2008-09-19 12:56:27 $
  *
- * Copyright 2006-2019 Kouhei Sutou <kou@cozmixng.org>
+ * Copyright 2006-2020 Sutou Kouhei <kou@cozmixng.org>
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
  *
@@ -55,7 +55,7 @@ RB_CAIRO_BEGIN_DECLS
 
 #ifdef __WIN32__
 #  ifdef RB_CAIRO_COMPILATION
-#    define RB_CAIRO_VAR __declspec(dllexport)
+#    define RB_CAIRO_VAR extern __declspec(dllexport)
 #  else
 #    define RB_CAIRO_VAR extern __declspec(dllimport)
 #  endif
@@ -65,7 +65,7 @@ RB_CAIRO_BEGIN_DECLS
 
 #define RB_CAIRO_VERSION_MAJOR 1
 #define RB_CAIRO_VERSION_MINOR 16
-#define RB_CAIRO_VERSION_MICRO 5
+#define RB_CAIRO_VERSION_MICRO 6
 
 RB_CAIRO_VAR VALUE rb_mCairo;
 RB_CAIRO_VAR VALUE rb_cCairo_Context;
